@@ -1,7 +1,4 @@
-try:
-    import json
-except:
-    import simplejson as json
+import json
 from oauth2client import xsrfutil
 from oauth2client.file import Storage
 from django.conf import settings
@@ -10,7 +7,7 @@ from django.core.exceptions import PermissionDenied
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseBadRequest, HttpResponseRedirect, Http404
 from django.utils.translation import ugettext as _
-from django.views.generic import TemplateView, View
+from django.views.generic import TemplateView, View, UpdateView
 from conf import settings as ls
 
 class AppOptionView(TemplateView):
@@ -38,7 +35,7 @@ class AppOptionView(TemplateView):
         from yawdadmin import admin_site
         context = super(AppOptionView, self).get_context_data(**kwargs)
         context['optionset_admin'] = admin_site.get_optionset_admin(self.kwargs['optionset_label'])(**self.get_form_kwargs())
-        context['title'] = '%s %s' % (context['optionset_admin'].verbose_name, _('Configuration'))
+        context['title'] = '%s' % (unicode(context['optionset_admin'].verbose_name))
         return context
     
     def post(self, request, *args, **kwargs):
@@ -134,4 +131,25 @@ def valid_analytics_view(request):
             raise PermissionDenied
     
     if not ls.ADMIN_GOOGLE_ANALYTICS_FLOW:
-        raise Http404
\ No newline at end of file
+        raise Http404
+    
+class MyAccountView(UpdateView):
+    template_name = 'registration/my_account.html'
+    form_class = ls.ADMIN_USER_MODELFORM
+    
+    def __init__(self, *args, **kwargs):
+        super(MyAccountView, self).__init__(*args, **kwargs)
+        self.success_url = reverse('admin:my-account')
+        
+    def form_valid(self, form):
+        messages.add_message(self.request, messages.SUCCESS, _('Your account has been updated successfuly.'))
+        return super(MyAccountView, self).form_valid(form)
+    
+    def get_object(self):
+        return self.request.user
+    
+    def get_context_data(self, **kwargs):
+        context = super(MyAccountView, self).get_context_data(**kwargs)
+        context['title'] = _('My account')
+        return context
+    
\ No newline at end of file
